@@ -29,7 +29,7 @@
 #include "fahrplan_utils.h"
 #include "fahrplan_gui.h"
 #include "fahrplan_parser.h"
-#include "fahrplan_parser_gisgraphy.h"
+#include "fahrplan_parser_openstreetmap.h"
 
 /**
  * OnClick Event for a HildonButton
@@ -49,7 +49,7 @@ void onAboutClicked(HildonButton * button, AppData *data) {
 	strcat(infoLabel, "<i>hcm</i> (various patches)\n");
 	strcat(infoLabel, "<i>thp</i> (hildon themed buttons)\n");
 	strcat(infoLabel, "<i>qwerty12</i> (two min crash)\n");
-	strcat(infoLabel, "<i>qbast</i> (gisgraphy backend)");
+	strcat(infoLabel, "<i>qbast</i> (openstreetmap backend)");
 
 
 	hildon_banner_show_information_with_markup(
@@ -163,13 +163,13 @@ void onGetStationByGPSClicked(HildonButton * button, AppData *data) {
 
 			GArray *result = getStationsByGPS(poslong, poslat, data);
 
-			/* Nothing found try gisgraphy backend */
+			/* Nothing found try openstreetmap backend */
 			if (result==NULL || result->len == 0) {
 
 				hildon_banner_show_information(
 						GTK_WIDGET(data->journeyWindow),
 						NULL,
-						_("Trying gisgraphy to find your city by location"));
+						_("Trying openstreetmap to find your city by location"));
 
 				gchar *cityname = getCityNameByGPS(data->currentGPSDevice->fix->longitude, data->currentGPSDevice->fix->latitude);
 
