@@ -355,8 +355,8 @@ ResultInfo * getJourneyData_mobilebahnde(gchar *fromStation, gchar *viaStation,
 		if (newUrl) {
 
 			gchar * postData = g_strdup_printf("REQ0JourneyStopsS0A=1&REQ0JourneyStopsS0K=%s&REQ0JourneyStopsS0ID=&REQ0JourneyStopsZ0A=1&REQ0JourneyStopsZ0K=%s&REQ0JourneyStopsZ0ID=&REQ0JourneyDate=%d.%d.%d&REQ0JourneyTime=%d:%d&REQ0HafasSearchForw=%d&existOptimizePrice=1&REQ0HafasOptimize1=0%3A1&existProductNahverkehr=yes&REQ0Tariff_TravellerAge.1=35&start=Suchen&REQ0Tariff_Class=2&REQ0Tariff_TravellerReductionClass.1=0", fromStation, toStation, day, month , year, hour, minutes, options);
-			gchar * url      = g_strdup_printf("http:%s",newUrl);
-			gchar * result   = performCurlRequest(url, postData);
+			mobilebahnde_applyMissingHttp(newUrl);
+			gchar * result   = performCurlRequest(newUrl, postData);
 
 			if (!result) {
 
@@ -817,8 +817,9 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 
 									testStr[strlen(testStr) - strlen(testStrLater)] = '\0';
 
-									resultInfo->headerEarlierUrl = g_strdup_printf("http:%se=2", testStr);
-									resultInfo->headerLaterUrl = g_strdup_printf("http:%se=1", testStr);
+									mobilebahnde_applyMissingHttp(testStr);
+									resultInfo->headerEarlierUrl = g_strdup_printf("%se=2", testStr);
+									resultInfo->headerLaterUrl = g_strdup_printf("%se=1", testStr);
 								}
 							}
 						}
@@ -867,6 +868,24 @@ ResultInfo * mobilebahnde_parseSearchResult(gchar *returnData) {
 	return resultInfo;
 }
 
+/**
+ * mobile.bahn.de does not always contain a leading http
+ */
+mobilebahnde_applyMissingHttp(gchar * url) {
+
+	char theUrl[4];
+	strncpy(theUrl, url, 4);
+	theUrl[4] = '\0';
+	gchar * newUrl;
+
+	if (strcmp(theUrl, "http")) {
+		newUrl = g_strdup_printf("http:%s",url);
+	} else {
+		newUrl = g_strdup_printf("%s",url);
+	}
+	strcpy(url, newUrl);
+
+}
 
 /**
  * Internal Helper for only mobile.bahn.de
@@ -909,7 +928,10 @@ GArray * mobilebahnde_getResultValues(xmlNode * a_node) {
 
 								if (!strcmp(cur_attribute->name, "href")) {
 
-									resultItem->detailsUrl = g_strdup_printf("http:%s", cur_attribute->children->content);
+									resultItem->detailsUrl = g_strdup_printf("%s", cur_attribute->children->content);
+									mobilebahnde_applyMissingHttp(resultItem->detailsUrl);
+									g_debug("details url:");
+									g_debug(resultItem->detailsUrl);
 								}
 							}
 
